@@ -100,5 +100,5 @@ def where(
         raise ValueError("either both or neither of x and y should be given")
 
     return Tensor._op(
-        Where, x, y, op_kwargs=dict(condition=condition), constant=constant
+        Where, x, y, op_kwargs={"condition": condition}, constant=constant
     )
