@@ -3,8 +3,8 @@ import numpy as np
 from mygrad.nnet.initializers.uniform import uniform
 
 
-def glorot_uniform(*shape, gain=1, dtype=np.float32, constant=False):
-    r""" Initialize a `Tensor` according to the uniform initialization procedure
+def glorot_uniform(*shape, gain=1, dtype=np.float32, constant=None):
+    r"""Initialize a `Tensor` according to the uniform initialization procedure
     described by Glorot and Bengio.
 
     Parameters
